@@ -32,11 +32,11 @@ Test::Run::Core - Base class to run standard TAP scripts.
 
 =head1 VERSION
 
-Version 0.0302
+Version 0.0303
 
 =cut
 
-$VERSION = '0.0302';
+$VERSION = '0.0303';
 
 $ENV{HARNESS_ACTIVE} = 1;
 $ENV{HARNESS_NG_VERSION} = $VERSION;
@@ -2101,13 +2101,6 @@ L<http://search.cpan.org/dist/Test::Run>
 
 =back
 
-=head1 SOURCE AVAILABILITY
-
-The latest source of Test::Run is available from its BerliOS Subversion
-repository:
-
-L<https://svn.berlios.de/svnroot/repos/web-cpan/Test-Harness-NG/>
-
 =head1 LICENSE
 
 This file is licensed under the MIT X11 License:
